==> nextcloud-app-mail-0.6.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/it.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Posta",
    "Error while loading the accounts." : "Errore durante il caricamento degli account.",
    "Fetching Aliases Failed." : "Recupero alias non riuscito.",
    "Saving Aliases Failed." : "Salvataggio alias non riuscito.",
    "Deleting Aliases Failed." : "Eliminazione alias non riuscita.",
    "Error while loading the selected account." : "Errore durante il caricamento dell'account selezionato.",
    "Loading {folder}" : "Caricamento {folder}",
    "Searching for {query}" : "Ricerca di {query}",
    "Forwarded message" : "Messaggio inoltrato",
    "Choose a folder to store the attachment in" : "Scegli una cartella dove salvare l'allegato",
    "Attachments saved to Files." : "Allegati salvati in File.",
    "Attachment saved to Files." : "Allegato salvato in File.",
    "Error while saving attachments to Files." : "Errore durante il salvataggio degli allegati in File.",
    "Error while saving attachment to Files." : "Errore durante il salvataggio dell'allegato in File.",
    "Message flag could not be set." : "Il contrassegno del messaggio non può essere impostato.",
    "Invalid account" : "Account non valido",
    "Invalid folder" : "Cartella non valida",
    "Unknown error" : "Errore sconosciuto",
    "Error while creating an account: " : "Errore durante la creazione di un account:",
    "Could not load {tag}{name}{endtag}" : "Impossibile caricare {tag}{name}{endtag}",
    "We couldn’t load {tag}{name}{endtag}" : "Impossibile caricare {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Si è verificato un programma durante il caricamento di {tag}{name}{endtag}",
    "We couldn’t load your message" : "Impossibile caricare il tuo messaggio",
    "Unable to load the desired message" : "Impossibile caricare messaggio desiderato",
    "There was a problem loading the message" : "Si è verificato un problema durante il caricamento del messaggio",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n nuovo messaggio in {folderName} \nda {from}","%n nuovi messaggi in {folderName} \nda {from}"],
    "Show all folders" : "Mostra tutte le cartelle",
    "Collapse folders" : "Contrai le cartelle",
    "Error while deleting account." : "Errore durante l'eliminazione dell'account.",
    "Choose a file to add as attachment" : "Scegli un file da aggiungere come allegato",
    "Reply" : "Rispondi",
    "Send" : "Invia",
    "Sending …" : "Invio in corso...",
    "Message sent!" : "Messaggio inviato!",
    "Server error" : "Errore del server",
    "An unknown error occurred" : "Si è verificato un errore sconosciuto",
    "Opening HTML drafts is not supported yet." : "L'apertura delle bozze HTML non è ancora supportata.",
    "Draft saved!" : "Bozza salvata!",
    "you" : "tu",
    "Send message to {email}" : "Invia messaggio a {email}",
    "No writable calendars found" : "Nessun calendario scrivibile trovato",
    "Error while importing the calendar event" : "Errore durante l'importazione dell'evento di calendario",
    "Error while downloading calendar event" : "Errore durante lo scaricamento dell'evento di calendario",
    "Error while deleting message." : "Errore durante l'eliminazione del messaggio.",
    "Error while loading messages." : "Errore durante il caricamento dei messaggi.",
    "Connecting" : "Connessione in corso",
    "Connect" : "Connetti",
    "Inbox" : "Posta in arrivo",
    "Sent" : "Posta inviata",
    "Drafts" : "Bozze",
    "Archive" : "Archivio",
    "Trash" : "Cestino",
    "Junk" : "Posta indesiderata",
    "All" : "Tutti",
    "Favorites" : "Preferiti",
    "Creating account failed: " : "Creazione account non riuscita:",
    "Auto detect failed. Please use manual mode." : "Rilevamento automatico non riuscito. Usa la modalità manuale.",
    "Delete permanently" : "Elimina definitivamente",
    "& others" : "e altri",
    "All inboxes" : "Tutte le caselle di posta",
    "Error loading message" : "Errore durante il caricamento del messaggio",
    "Forwarding to %s" : "Inoltro a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Fai clic qui se non viene rediretto automaticamente entro pochi secondi.",
    "Redirect" : "Redirigi",
    "The link leads to %s" : "Il collegamento conduce a %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Se non vuoi visitare tale pagina, puoi tornare all'<a href=\"%s\">applicazione di posta</a>.",
    "Continue to %s" : "Continua su %s",
    "Settings" : "Impostazioni",
    "Delete account" : "Elimina account",
    "Account Settings" : "Impostazioni account",
    "Aliases" : "Alias",
    "Mail address" : "Indirizzo di posta",
    "Display Name" : "Nome visualizzato",
    "Save" : "Salva",
    "Add attachment from Files" : "Aggiungi allegato da File",
    "from" : "da",
    "to" : "a",
    "cc" : "cc",
    "bcc" : "ccn",
    "Subject" : "Oggetto",
    "Import into calendar" : "Importa nel calendario",
    "Download attachment" : "Scarica allegato",
    "Save to Files" : "Salva in File",
    "Save all to Files" : "Salva tutto in File",
    "The images have been blocked to protect your privacy." : "Le immagini sono state bloccate per proteggere la tua riservatezza.",
    "Show images from this sender" : "Mostra immagini da questo mittente",
    "Forward" : "Inoltra",
    "New message" : "Nuovo messaggio",
    "No search results for" : "Nessun risultato di ricerca per",
    "Add mail account" : "Aggiungi account di posta",
    "Connect your mail account" : "Connetti il tuo account di posta",
    "Name" : "Nome",
    "Mail Address" : "Indirizzo di posta",
    "Password" : "Password",
    "Manual configuration" : "Configurazione manuale",
    "IMAP Host" : "Host IMAP",
    "IMAP security" : "Sicurezza IMAP",
    "None" : "Nessuna",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Porta IMAP",
    "IMAP User" : "Utente IMAP",
    "IMAP Password" : "Password IMAP",
    "SMTP Host" : "Host SMTP",
    "SMTP security" : "Sicurezza SMTP",
    "SMTP Port" : "Porta SMTP",
    "SMTP User" : "Utente SMTP",
    "SMTP Password" : "Password SMTP"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-0.7.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/it.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Posta",
    "Error while loading the accounts." : "Errore durante il caricamento degli account.",
    "Error while loading the selected account." : "Errore durante il caricamento dell'account selezionato.",
    "Can not load this folder." : "Impossibile caricare questa cartella.",
    "Loading {folder}" : "Caricamento {folder}",
    "Searching for {query}" : "Ricerca di {query}",
    "Error while deleting message." : "Errore durante l'eliminazione del messaggio.",
    "Forwarded message" : "Messaggio inoltrato",
    "Choose a folder to store the attachment in" : "Scegli una cartella dove salvare l'allegato",
    "Attachments saved to Files." : "Allegati salvati in File.",
    "Attachment saved to Files." : "Allegato salvato in File.",
    "Error while saving attachments to Files." : "Errore durante il salvataggio degli allegati in File.",
    "Error while saving attachment to Files." : "Errore durante il salvataggio dell'allegato in File.",
    "Message flag could not be set." : "Il contrassegno del messaggio non può essere impostato.",
    "Could not move message." : "Impossibile spostare il messaggio.",
    "Invalid account" : "Account non valido",
    "Invalid folder" : "Cartella non valida",
    "Error while creating the account: " : "Errore durante la creazione dell'account:",
    "Unknown error" : "Errore sconosciuto",
    "All inboxes" : "Tutte le caselle di posta",
    "Could not load {tag}{name}{endtag}" : "Impossibile caricare {tag}{name}{endtag}",
    "We couldn’t load {tag}{name}{endtag}" : "Impossibile caricare {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Si è verificato un programma durante il caricamento di {tag}{name}{endtag}",
    "We couldn’t load your message" : "Impossibile caricare il tuo messaggio",
    "Unable to load the desired message" : "Impossibile caricare messaggio desiderato",
    "There was a problem loading the message" : "Si è verificato un problema durante il caricamento del messaggio",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Show all folders" : "Mostra tutte le cartelle",
    "Collapse folders" : "Contrai le cartelle",
    "Error while deleting account." : "Errore durante l'eliminazione dell'account.",
    "Choose a file to add as attachment" : "Scegli un file da aggiungere come allegato",
    "An error occurred while uploading {fname}" : "Si è verificato un errore durante il caricamento di {fname}",
    "Reply" : "Rispondi",
    "Send" : "Invia",
    "Sending …" : "Invio in corso...",
    "Message sent!" : "Messaggio inviato!",
    "Server error" : "Errore del server",
    "An unknown error occurred" : "Si è verificato un errore sconosciuto",
    "Opening HTML drafts is not supported yet." : "L'apertura delle bozze HTML non è ancora supportata.",
    "Draft saved!" : "Bozza salvata!",
    "you" : "tu",
    "Send message to {email}" : "Invia messaggio a {email}",
    "No writable calendars found" : "Nessun calendario scrivibile trovato",
    "Error while importing the calendar event" : "Errore durante l'importazione dell'evento di calendario",
    "Error while downloading calendar event" : "Errore durante lo scaricamento dell'evento di calendario",
    "Error while loading messages." : "Errore durante il caricamento dei messaggi.",
    "Error while refreshing messages." : "Errore durante l'aggiornamento dei messaggi.",
    "Setting up your account" : "Configurazione del tuo account",
    "Inbox" : "Posta in arrivo",
    "Sent" : "Posta inviata",
    "Drafts" : "Bozze",
    "Archive" : "Archivio",
    "Trash" : "Cestino",
    "Junk" : "Posta indesiderata",
    "All" : "Tutti",
    "Favorites" : "Preferiti",
    "Creating account failed: " : "Creazione account non riuscita:",
    "Auto detect failed. Please use manual mode." : "Rilevamento automatico non riuscito. Usa la modalità manuale.",
    "Delete permanently" : "Elimina definitivamente",
    "& others" : "e altri",
    "Error loading message" : "Errore durante il caricamento del messaggio",
    "Settings" : "Impostazioni",
    "Forwarding to %s" : "Inoltro a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Fai clic qui se non viene rediretto automaticamente entro pochi secondi.",
    "Redirect" : "Redirigi",
    "The link leads to %s" : "Il collegamento conduce a %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Se non vuoi visitare tale pagina, puoi tornare all'<a href=\"%s\">applicazione di posta</a>.",
    "Continue to %s" : "Continua su %s",
    "Delete account" : "Elimina account",
    "Try again" : "Riprova",
    "New message" : "Nuovo messaggio",
    "Account Settings" : "Impostazioni account",
    "Aliases" : "Alias",
    "Mail address" : "Indirizzo di posta",
    "Display Name" : "Nome visualizzato",
    "Save" : "Salva",
    "Keyboard shortcuts" : "Scorciatoie da tastiera",
    "Speed up your Mail experience with these quick shortcuts." : "Velocizza la tua esperienza di posta elettronica con queste scorciatoie.",
    "Compose new message" : "Componi nuovo messaggio",
    "Newer message" : "Messaggio più recente",
    "Older message" : "Messaggio più datato",
    "Toggle star" : "Commuta stella",
    "Toggle unread" : "Commuta non letto",
    "Delete" : "Elimina",
    "Search" : "Cerca",
    "Refresh" : "Aggiorna",
    "Connect your mail account" : "Connetti il tuo account di posta",
    "Name" : "Nome",
    "Mail Address" : "Indirizzo di posta",
    "Password" : "Password",
    "Manual configuration" : "Configurazione manuale",
    "IMAP Host" : "Host IMAP",
    "IMAP security" : "Sicurezza IMAP",
    "None" : "Nessuna",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Porta IMAP",
    "IMAP User" : "Utente IMAP",
    "IMAP Password" : "Password IMAP",
    "SMTP Host" : "Host SMTP",
    "SMTP security" : "Sicurezza SMTP",
    "SMTP Port" : "Porta SMTP",
    "SMTP User" : "Utente SMTP",
    "SMTP Password" : "Password SMTP",
    "Connect" : "Connetti",
    "from" : "da",
    "to" : "a",
    "cc" : "cc",
    "bcc" : "ccn",
    "Subject" : "Oggetto",
    "Save all to Files" : "Salva tutto in File",
    "Add mail account" : "Aggiungi account di posta",
    "No search results for" : "Nessun risultato di ricerca per",
    "The images have been blocked to protect your privacy." : "Le immagini sono state bloccate per proteggere la tua riservatezza.",
    "Show images from this sender" : "Mostra immagini da questo mittente",
    "Forward" : "Inoltra",
    "Add attachment" : "Aggiungi allegato",
    "Add from Files" : "Aggiungi da File",
    "Import into calendar" : "Importa nel calendario",
    "Download attachment" : "Scarica allegato",
    "Save to Files" : "Salva in File"
},
"nplurals=2; plural=(n != 1);");
